@@ -498,7 +498,7 @@ def obj_to_path(obj):
     ...     class B:
     ...         def bar(self, x): ...
     ...
-    >>> for t in [(A, ('foo',)), (A, ('B',)), (A, ('B', 'bar'))]:
+    >>> for t in [(A, ('foo',)), (A, ('B',)), (A, ('B', 'bar'))]: # doctest: +SKIP
     ...     print(obj_to_path(path_to_obj(*t)))
     ...     print(t)
     ...     print()
